@@ -83,7 +83,10 @@ lasground.LAS = function(las, algorithm, last_returns = TRUE)
       warning("'ReturnNumber' and/or 'NumberOfReturns' not found. Cannot use the option 'last_returns', all the points will be used.", call. = FALSE)
     } else {
       filter <- parse_filter(las, ~ReturnNumber == NumberOfReturns)
-      if (sum(filter) == 0) warning("Zero last return found. Cannot use the option 'last_returns', all the points will be used.")
+      if (sum(filter) == 0) {
+        warning("Zero last return found. Cannot use the option 'last_returns', all the points will be used.", call. = FALSE)
+        filter <- TRUE
+      }
     }
   }
 
