@@ -42,7 +42,7 @@ test_that("tsearch works", {
   expect_true(is.na(ts))
 })
 
-test_that("tsearch pass computer precision tests", {
+test_that("tsearch passes computer precision tests", {
   x <- c(6.89, 7.15, 7.03)
   y <- c(7.76, 7.75, 8.35)
   P <- cbind(x,y)
@@ -80,6 +80,47 @@ test_that("tsearch pass computer precision tests", {
   expect_equal(ts, 1L)
 })
 
+test_that("tsearch passes computer precision tests", {
+
+  P = structure(c(
+    488094.617850573, 488094.682850573, 488095.461850573,
+    5189348.04894701, 5189348.79694701, 5189348.25294701),
+    .Dim = 3:2, .Dimnames = list(NULL, c("X", "Y")))
+
+  X = matrix(c(488094.75, 5189348.75), nrow = 1)
+
+  D = matrix(3:1, nrow = 1)
+
+  expect_equal(lidR:::tSearch(D,P, X, 1), 1L)
+
+  D = matrix(c(2,3,1), nrow = 1)
+
+  expect_equal(lidR:::tSearch(D,P, X, 1), 1L)
+
+  D = matrix(1:3, nrow = 1)
+
+  expect_equal(lidR:::tSearch(D,P, X, 1), 1L)
+
+  P = structure(c(
+    488100.025850573, 488099.663850573, 488099.916850573,
+    5189337.35594701, 5189337.44894701, 5189336.86194701),
+    .Dim = 3:2, .Dimnames = list(NULL, c("X", "Y")))
+
+  X = structure(c(488099.75, 5189337.25), .Dim = 1:2)
+
+  D = matrix(1:3, nrow = 1)
+
+  expect_equal(lidR:::tSearch(D,P, X, 1), 1L)
+
+  D = matrix(3:1, nrow = 1)
+
+  expect_equal(lidR:::tSearch(D,P, X, 1), 1L)
+
+  D = matrix(c(2,3,1), nrow = 1)
+
+  expect_equal(lidR:::tSearch(D,P, X, 1), 1L)
+})
+
 test_that("tinfo works", {
   x <- c(0, 1, 0)
   y <- c(0, 0, 1)
